===============================================
Update manual package installation (deprecated)
===============================================

.. warning::

    Manual package installation is deprecated and will be removed in the next
    major version of ``icemac.addressbook``.

Please :ref:`upgrade-to-guided-installation`.
